# Clothoids

Fork of [Clothoids](https://github.com/ebertolazzi/Clothoids) by Enrico Bertolazzi.

This is just a fork that tries its best to keep stable releases and stay up-to-date.

Unless it relates directly to something here (e.g., a broken release) please refer to the original repo!
